"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SyncJsonFileAdapter = exports.JsonFileAdapter = void 0;
const fs = __importStar(require("fs"));
const path = __importStar(require("path"));
const fs_help_1 = require("./fs_help");
/**
 * JsonFileAdapter is an async adapter for working with Json Files
 *
 * @author Nicolas Schmidt
 */
class JsonFileAdapter {
    /**
     * The constructor for JsonFileAdapter
     *
     * @param path the path to a json file to save to and load from
     * @param settings The settings for the JsonFileAdapter:<br/>
     *   beautify - should the generated json be beautified (default: false)<br/>
     *   beautify_space - the space to indent the json with (default: 2)
     *
     * @author Nicolas Schmidt
     *
     * @see JsonFileAdapter - 👩‍👦 the parent class
     */
    constructor(
    /**
     * The path of the JsonFileAdapter
     *
     * @author Nicolas Schmidt
     *
     * @see JsonFileAdapter - 👩‍👦 the parent class
     */
    path, settings = {}) {
        this.path = path;
        this.settings = createDefaultSettings(settings);
    }
    /**
     * Saves the given data to the file the adapter refers to
     *
     * @param data The data to save
     * @returns ⌛ Promise (Ready when saved) >> ⛔ void
     *
     * @author Nicolas Schmidt
     *
     * @see JsonFileAdapter - 👩‍👦 the parent class
     */
    save(data) {
        return new Promise((rs, rj) => fs_help_1.mkdirs(path.dirname(this.path)).then(() => fs.writeFile(this.path, generateJson(data, this.settings), err => {
            if (err)
                rj(err);
            else
                rs();
        })));
    }
    /**
     * Loads data from the file the adapter refers to
     *
     * @returns ⌛ Promise (Ready when saved) >> Object
     *
     * @author Nicolas Schmidt
     *
     * @see JsonFileAdapter - 👩‍👦 the parent class
     */
    load() {
        return new Promise((rs, rj) => {
            fs.exists(this.path, exists => {
                if (exists) {
                    fs.readFile(this.path, (err, data) => {
                        if (err)
                            rj(err);
                        else
                            rs(JSON.parse(data.toString()));
                    });
                }
                else
                    rs({});
            });
        });
    }
}
exports.JsonFileAdapter = JsonFileAdapter;
/**
 * SyncJsonFileAdapter is an sync adapter for working with Json Files
 *
 * @author Nicolas Schmidt
 */
class SyncJsonFileAdapter {
    /**
     * The constructor for SyncJsonFileAdapter
     *
     * @param path the path to a json file to save to and load from
     * @param settings The settings for the SyncJsonFileAdapter:<br/>
     *   beautify - should the generated json be beautified (default: false)<br/>
     *   beautify_space - the space to indent the json with (default: 2)
     *
     * @author Nicolas Schmidt
     *
     * @see SyncJsonFileAdapter - 👩‍👦 the parent class
     */
    constructor(
    /**
     * The path of the SyncJsonFileAdapter
     *
     * @author Nicolas Schmidt
     *
     * @see SyncJsonFileAdapter - 👩‍👦 the parent class
     */
    path, settings = {}) {
        this.path = path;
        this.settings = createDefaultSettings(settings);
    }
    /**
     * Saves the given data to the file the adapter refers to
     *
     * @param data The data to save
     * @returns ⌛ Promise (Ready when saved) >> ⛔ void
     *
     * @author Nicolas Schmidt
     *
     * @see SyncJsonFileAdapter - 👩‍👦 the parent class
     */
    save(data) {
        fs_help_1.mkdirsSync(path.dirname(this.path));
        fs.writeFileSync(this.path, generateJson(data, this.settings));
    }
    /**
     * Loads data from the file the adapter refers to
     *
     * @returns ⌛ Promise (Ready when saved) >> Object
     *
     * @author Nicolas Schmidt
     *
     * @see SyncJsonFileAdapter - 👩‍👦 the parent class
     */
    load() {
        if (fs.existsSync(this.path))
            return JSON.parse(fs.readFileSync(this.path).toString());
        return {};
    }
}
exports.SyncJsonFileAdapter = SyncJsonFileAdapter;
// ----------------------------------------------------------
// Purely functional, not exported, just used by the adapters
function generateJson(object, settings) {
    return settings.beautify ?
        JSON.stringify(object, null, settings.beautify_space) :
        JSON.stringify(object);
}
function createDefaultSettings(settings) {
    settings.beautify = settings.beautify || false;
    settings.beautify_space = settings.beautify_space || 2;
    return settings;
}
//# sourceMappingURL=src/sourcemaps/json_adapter.js.map