import { DatabaseAdapter, JSObject, SyncDatabaseAdapter } from './database';
/**
 * XMLFileAdapter is an async adapter for working with XML Files
 *
 * @author Nicolas Schmidt
 */
export declare class XMLFileAdapter implements DatabaseAdapter {
    /**
     * The path of the XMLFileAdapter
     *
     * @author Nicolas Schmidt
     *
     * @see XMLFileAdapter - 👩‍👦 the parent class
     */
    readonly path: string;
    /**
     * The settings for the XMLFileAdapter: <br/>
     *   beautify - should the generated xml be beautified (default: false)
     *
     * @author Nicolas Schmidt
     *
     * @see XMLFileAdapter - 👩‍👦 the parent class
     */
    readonly settings: XMLAdapterSettings;
    /**
     * The constructor for XMLFileAdapter
     *
     * @param path the path to a xml file to save to and load from
     * @param settings The settings for the XMLFileAdapter:<br/>
     *   beautify - should the generated xml be beautified (default: false)
     *
     * @author Nicolas Schmidt
     *
     * @see XMLFileAdapter - 👩‍👦 the parent class
     */
    constructor(
    /**
     * The path of the XMLFileAdapter
     *
     * @author Nicolas Schmidt
     *
     * @see XMLFileAdapter - 👩‍👦 the parent class
     */
    path: string, settings?: XMLAdapterSettingsInput);
    /**
     * Saves the given data to the file the adapter refers to
     *
     * @param data The data to save
     * @returns ⌛ Promise (Ready when saved) >> ⛔ void
     *
     * @author Nicolas Schmidt
     *
     * @see XMLFileAdapter - 👩‍👦 the parent class
     */
    save(data: JSObject): Promise<void>;
    /**
     * Loads data from the file the adapter refers to
     *
     * @returns ⌛ Promise (Ready when saved) >> Object
     *
     * @author Nicolas Schmidt
     *
     * @see XMLFileAdapter - 👩‍👦 the parent class
     */
    load(): Promise<JSObject>;
}
/**
 * SyncXMLFileAdapter is an sync adapter for working with XML Files
 *
 * @author Nicolas Schmidt
 */
export declare class SyncXMLFileAdapter implements SyncDatabaseAdapter {
    /**
     * The path of the SyncXMLFileAdapter
     *
     * @author Nicolas Schmidt
     *
     * @see SyncXMLFileAdapter - 👩‍👦 the parent class
     */
    readonly path: string;
    /**
     * The settings for the SyncXMLFileAdapter: <br/>
     *   beautify - should the generated xml be beautified (default: false)
     *
     * @author Nicolas Schmidt
     *
     * @see SyncXMLFileAdapter - 👩‍👦 the parent class
     */
    readonly settings: XMLAdapterSettings;
    /**
     * The constructor for SyncXMLFileAdapter
     *
     * @param path the path to a xml file to save to and load from
     * @param settings The settings for the SyncXMLFileAdapter:<br/>
     *   beautify - should the generated xml be beautified (default: false)
     *
     * @author Nicolas Schmidt
     *
     * @see SyncXMLFileAdapter - 👩‍👦 the parent class
     */
    constructor(
    /**
     * The path of the SyncXMLFileAdapter
     *
     * @author Nicolas Schmidt
     *
     * @see SyncXMLFileAdapter - 👩‍👦 the parent class
     */
    path: string, settings?: XMLAdapterSettingsInput);
    /**
     * Saves the given data to the file the adapter refers to
     *
     * @param data The data to save
     * @returns ⌛ Promise (Ready when saved) >> ⛔ void
     *
     * @author Nicolas Schmidt
     *
     * @see SyncXMLFileAdapter - 👩‍👦 the parent class
     */
    save(data: JSObject): void;
    /**
     * Loads data from the file the adapter refers to
     *
     * @returns ⌛ Promise (Ready when saved) >> Object
     *
     * @author Nicolas Schmidt
     *
     * @see SyncXMLFileAdapter - 👩‍👦 the parent class
     */
    load(): JSObject;
}
/**
 * The settings for XMLFileAdapter or SyncXMLFileAdapter:<br/>
 *   beautify - should the generated xml be beautified (default: false)
 *
 * This is the input version of the interface. It get's applied all default values when passed to a XMLFileAdapter or SyncXMLFileAdapter
 *
 * @author Nicolas Schmidt
 *
 * @see XMLFileAdapter
 * @see SyncXMLFileAdapter
 */
export interface XMLAdapterSettingsInput {
    beautify?: false;
}
/**
 * The settings for XMLFileAdapter or SyncXMLFileAdapter:<br/>
 *   beautify - should the generated xml be beautified (default: false)
 *
 * @author Nicolas Schmidt
 *
 * @see XMLFileAdapter
 * @see SyncXMLFileAdapter
 */
export interface XMLAdapterSettings {
    beautify: false;
}
