"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SyncXMLFileAdapter = exports.XMLFileAdapter = void 0;
const fs = __importStar(require("fs"));
const path = __importStar(require("path"));
const fs_help_1 = require("./fs_help");
// xmlbuilder2 import. Throw an error if it is not installed
let xml;
try {
    xml = require('xmlbuilder2');
}
catch (e) {
    let err = new Error("You should have installed xmlbuilder2 if you want to use the xml-adapter");
    err.stack += '\nCaused by: ' + err.message + err.stack;
    throw e;
}
/**
 * XMLFileAdapter is an async adapter for working with XML Files
 *
 * @author Nicolas Schmidt
 */
class XMLFileAdapter {
    /**
     * The constructor for XMLFileAdapter
     *
     * @param path the path to a xml file to save to and load from
     * @param settings The settings for the XMLFileAdapter:<br/>
     *   beautify - should the generated xml be beautified (default: false)
     *
     * @author Nicolas Schmidt
     *
     * @see XMLFileAdapter - 👩‍👦 the parent class
     */
    constructor(
    /**
     * The path of the XMLFileAdapter
     *
     * @author Nicolas Schmidt
     *
     * @see XMLFileAdapter - 👩‍👦 the parent class
     */
    path, settings = {}) {
        this.path = path;
        this.settings = createDefaultSettings(settings);
    }
    /**
     * Saves the given data to the file the adapter refers to
     *
     * @param data The data to save
     * @returns ⌛ Promise (Ready when saved) >> ⛔ void
     *
     * @author Nicolas Schmidt
     *
     * @see XMLFileAdapter - 👩‍👦 the parent class
     */
    save(data) {
        return new Promise((rs, rj) => fs_help_1.mkdirs(path.dirname(this.path)).then(() => fs.writeFile(this.path, generateXML(data, this.settings), err => {
            if (err)
                rj(err);
            else
                rs();
        })));
    }
    /**
     * Loads data from the file the adapter refers to
     *
     * @returns ⌛ Promise (Ready when saved) >> Object
     *
     * @author Nicolas Schmidt
     *
     * @see XMLFileAdapter - 👩‍👦 the parent class
     */
    load() {
        return new Promise((rs, rj) => {
            fs.exists(this.path, exists => {
                if (exists) {
                    fs.readFile(this.path, (err, data) => {
                        if (err)
                            rj(err);
                        else
                            rs(xml.create(data.toString()).end({ format: 'object' }));
                    });
                }
                else
                    rs({});
            });
        });
    }
}
exports.XMLFileAdapter = XMLFileAdapter;
/**
 * SyncXMLFileAdapter is an sync adapter for working with XML Files
 *
 * @author Nicolas Schmidt
 */
class SyncXMLFileAdapter {
    /**
     * The constructor for SyncXMLFileAdapter
     *
     * @param path the path to a xml file to save to and load from
     * @param settings The settings for the SyncXMLFileAdapter:<br/>
     *   beautify - should the generated xml be beautified (default: false)
     *
     * @author Nicolas Schmidt
     *
     * @see SyncXMLFileAdapter - 👩‍👦 the parent class
     */
    constructor(
    /**
     * The path of the SyncXMLFileAdapter
     *
     * @author Nicolas Schmidt
     *
     * @see SyncXMLFileAdapter - 👩‍👦 the parent class
     */
    path, settings = {}) {
        this.path = path;
        this.settings = createDefaultSettings(settings);
    }
    /**
     * Saves the given data to the file the adapter refers to
     *
     * @param data The data to save
     * @returns ⌛ Promise (Ready when saved) >> ⛔ void
     *
     * @author Nicolas Schmidt
     *
     * @see SyncXMLFileAdapter - 👩‍👦 the parent class
     */
    save(data) {
        fs_help_1.mkdirsSync(path.dirname(this.path));
        fs.writeFileSync(this.path, generateXML(data, this.settings));
    }
    /**
     * Loads data from the file the adapter refers to
     *
     * @returns ⌛ Promise (Ready when saved) >> Object
     *
     * @author Nicolas Schmidt
     *
     * @see SyncXMLFileAdapter - 👩‍👦 the parent class
     */
    load() {
        if (fs.existsSync(this.path))
            return xml.create(fs.readFileSync(this.path).toString()).end({ format: 'object' });
        return {};
    }
}
exports.SyncXMLFileAdapter = SyncXMLFileAdapter;
// ----------------------------------------------------------
// Purely functional, not exported, just used by the adapters
function generateXML(object, settings) {
    return xml.create(object).end({ prettyPrint: settings.beautify, format: "xml" }).toString();
}
function createDefaultSettings(settings) {
    settings.beautify = settings.beautify || false;
    return settings;
}
//# sourceMappingURL=src/sourcemaps/xml_adapter.js.map