import { DatabaseAdapter, JSObject, SyncDatabaseAdapter } from './database';
/**
 * YamlFileAdapter is an async adapter for working with Yaml Files
 *
 * @author Nicolas Schmidt
 */
export declare class YamlFileAdapter implements DatabaseAdapter {
    readonly path: string;
    /**
     * The constructor for YamlFileAdapter
     *
     * @param path the path to a yaml file to save to and load from
     *
     * @author Nicolas Schmidt
     *
     * @see YamlFileAdapter - 👩‍👦 the parent class
     */
    constructor(path: string);
    /**
     * Saves the given data to the file the adapter refers to
     *
     * @param data The data to save
     * @returns ⌛ Promise (Ready when saved) >> ⛔ void
     *
     * @author Nicolas Schmidt
     *
     * @see YamlFileAdapter - 👩‍👦 the parent class
     */
    save(data: JSObject): Promise<void>;
    /**
     * Loads data from the file the adapter refers to
     *
     * @returns ⌛ Promise (Ready when saved) >> Object
     *
     * @author Nicolas Schmidt
     *
     * @see YamlFileAdapter - 👩‍👦 the parent class
     */
    load(): Promise<JSObject>;
}
/**
 * SyncYamlFileAdapter is an sync adapter for working with Yaml Files
 *
 * @author Nicolas Schmidt
 */
export declare class SyncYamlFileAdapter implements SyncDatabaseAdapter {
    readonly path: string;
    /**
     * The constructor for SyncYamlFileAdapter
     *
     * @param path the path to a yaml file to save to and load from
     *
     * @author Nicolas Schmidt
     *
     * @see SyncYamlFileAdapter - 👩‍👦 the parent class
     */
    constructor(path: string);
    /**
     * Saves the given data to the file the adapter refers to
     *
     * @param data The data to save
     * @returns ⌛ Promise (Ready when saved) >> ⛔ void
     *
     * @author Nicolas Schmidt
     *
     * @see SyncYamlFileAdapter - 👩‍👦 the parent class
     */
    save(data: JSObject): void;
    /**
     * Loads data from the file the adapter refers to
     *
     * @returns ⌛ Promise (Ready when saved) >> Object
     *
     * @author Nicolas Schmidt
     *
     * @see SyncYamlFileAdapter - 👩‍👦 the parent class
     */
    load(): JSObject;
}
