"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SyncYamlFileAdapter = exports.YamlFileAdapter = void 0;
const fs = __importStar(require("fs"));
const path = __importStar(require("path"));
const fs_help_1 = require("./fs_help");
// js-yaml import. Throw an error if it is not installed
let yaml;
try {
    yaml = require('js-yaml');
}
catch (e) {
    let err = new Error("You should have installed js-yaml if you want to use the yaml-adapter");
    err.stack += '\nCaused by: ' + err.message + err.stack;
    throw e;
}
/**
 * YamlFileAdapter is an async adapter for working with Yaml Files
 *
 * @author Nicolas Schmidt
 */
class YamlFileAdapter {
    /**
     * The constructor for YamlFileAdapter
     *
     * @param path the path to a yaml file to save to and load from
     *
     * @author Nicolas Schmidt
     *
     * @see YamlFileAdapter - 👩‍👦 the parent class
     */
    constructor(path) {
        this.path = path;
    }
    /**
     * Saves the given data to the file the adapter refers to
     *
     * @param data The data to save
     * @returns ⌛ Promise (Ready when saved) >> ⛔ void
     *
     * @author Nicolas Schmidt
     *
     * @see YamlFileAdapter - 👩‍👦 the parent class
     */
    save(data) {
        return new Promise((rs, rj) => fs_help_1.mkdirs(path.dirname(this.path)).then(() => fs.writeFile(this.path, yaml.dump(data), err => {
            if (err)
                rj(err);
            else
                rs();
        })));
    }
    /**
     * Loads data from the file the adapter refers to
     *
     * @returns ⌛ Promise (Ready when saved) >> Object
     *
     * @author Nicolas Schmidt
     *
     * @see YamlFileAdapter - 👩‍👦 the parent class
     */
    load() {
        return new Promise((rs, rj) => {
            fs.exists(this.path, exists => {
                if (exists) {
                    fs.readFile(this.path, (err, data) => {
                        if (err)
                            rj(err);
                        else
                            rs(yaml.load(data.toString()));
                    });
                }
                else
                    rs({});
            });
        });
    }
}
exports.YamlFileAdapter = YamlFileAdapter;
/**
 * SyncYamlFileAdapter is an sync adapter for working with Yaml Files
 *
 * @author Nicolas Schmidt
 */
class SyncYamlFileAdapter {
    /**
     * The constructor for SyncYamlFileAdapter
     *
     * @param path the path to a yaml file to save to and load from
     *
     * @author Nicolas Schmidt
     *
     * @see SyncYamlFileAdapter - 👩‍👦 the parent class
     */
    constructor(path) {
        this.path = path;
    }
    /**
     * Saves the given data to the file the adapter refers to
     *
     * @param data The data to save
     * @returns ⌛ Promise (Ready when saved) >> ⛔ void
     *
     * @author Nicolas Schmidt
     *
     * @see SyncYamlFileAdapter - 👩‍👦 the parent class
     */
    save(data) {
        fs_help_1.mkdirsSync(path.dirname(this.path));
        fs.writeFileSync(this.path, yaml.dump(data));
    }
    /**
     * Loads data from the file the adapter refers to
     *
     * @returns ⌛ Promise (Ready when saved) >> Object
     *
     * @author Nicolas Schmidt
     *
     * @see SyncYamlFileAdapter - 👩‍👦 the parent class
     */
    load() {
        if (fs.existsSync(this.path))
            return yaml.load(fs.readFileSync(this.path).toString());
        return {};
    }
}
exports.SyncYamlFileAdapter = SyncYamlFileAdapter;
//# sourceMappingURL=src/sourcemaps/yaml_adapter.js.map